{ inputs, config, pkgs, ... }:

{
    imports = [
        (import ./utils/desktop.nix { inherit inputs config pkgs; })
    ];

    programs.ssh.matchBlocks."*".identityFile = "/home/user/.secrets/SSH/Arendia/id_ed25519";

    home.packages = with pkgs; [
        distrobox
        gnome-disk-utility
        moonlight-qt
        vscode
        texliveFull
        zed-editor
    ];

    services.hyprpaper = {
        settings = {
            wallpaper = [
                "HDMI-A-1,${./hyprland/files/wallpaper.png}"
                "eDP-1,${./hyprland/files/wallpaper.png}"
            ];
        };
    };

    # wayland.windowManager.hyprland.settings.env = ["WLR_DRM_DEVICES,/dev/dri/by-path/pci-0000:01:00.0-card"]; # Nvidia
    # wayland.windowManager.hyprland.settings.env = ["WLR_DRM_DEVICES,/dev/dri/by-path/pci-0000:00:02.0-card"]; # Intel
    wayland.windowManager.hyprland.settings = {
        exec-once = [
            # "${pkgs.swaylock-fancy}/bin/swaylock-fancy"
        ];
        monitor = [
            "eDP-1,1920x1080@60,0x0,1.25"
            "HDMI-A-1,1920x1080@60,0x-1080,1"
        ];
        bind = [
            ", XF86PowerOff, exec, ${pkgs.rofi}/bin/rofi -show power-menu -modi power-menu:${
            ./hyprland/files/rofi-power-menu.sh
        }"
        ];
        general.gaps_out = 1;
    };

    programs.alacritty.settings.font.size = 13;
    programs.kitty.font.size = 13;
    programs.zsh.initExtra = pkgs.lib.mkForce ''
      LOCAL_SEARCH_DIRS=(~/.dotfiles/)
      REMOTE_SEARCH_DIRS=( ~/Workspace)
    '';
}
